---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2011-12-22;214
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20111227&codiceRedaz=011G0256&dataVigenza=20251104
dataGU: 20111227
codiceRedaz: 011G0256
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 6 dicembre 2011, n. 201, recante disposizioni urgenti per la crescita, l'equita' e il consolidamento dei conti pubblici. (11G0256)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 6 dicembre 2011, n. 201, recante disposizioni urgenti per la crescita, l'equita' e il consolidamento dei conti pubblici, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

